@@ -16,15 +16,16 @@ class BoaVistaData(BaseData):
 
     Default Properties
     ==================
-    * tax_id (str):                     The TaxId prospected.
+    * tax_id (str)                      The TaxId prospected.
                                         must be a valid CNPJ, formatted or not.
-    * integration_status (str):         The current Integration Status, please check the
+    * integration_status (str)          The current Integration Status, please check the
                                         `find_current_status` method for more info.
-    * status_reason (str):              The human friendly reason for current status
-    * prospect_date (datetime):         The prospect datetime.
-    * payload (dict):                   Original payload received from prospection.
-    * timeit                            Time in seconds for retrieving data.
-    * datasource_base_url               Data Source Base Url
+    * status_reason (str)               The human friendly reason for current status
+    * prospect_date (datetime)          The prospect datetime.
+    * payload (dict)                    Original payload received from prospection.
+    * timeit (str)                      Time in seconds for retrieving data.
+    * datasource_base_url (str)         Data Source Base Url
+    * data_type (str)                   DataSource Object Name
 
     Boa Vista Properties
     ====================
