@@ -62,6 +62,8 @@ class SecretManager:
                         "/datasource/dev/snatch",
                         "/datasource/staging/snatch",
                         "/datasource/production/snatch",
+                        "/datasource/stg/snatch",
+                        "/datasource/prd/snatch",
                     ],
                 },
             ],
